@echo off
set is_extracted=1
if not exist psy_checker\win32\PsySystemCheck.exe (
    set is_extracted=0
)
if not exist psy_checker\win64\PsySystemCheck.exe (
    set is_extracted=0
)

if "%is_extracted%" equ "0" (
    call :MsgBox "Please extract the package (support_customer*.zip) first and run CollectLogs.bat again in the extracted folder." "vbOKOnly+vbExclamation+vbSystemModal" "Missing required files and dependencies"
    exit /b 1
)

call :MsgBox "Thank you for helping us improve our app. This script will collect some basic information about your system, along with some event information from our app. This information will be sent to us by the script so that we can more closely diagnose your situation."+vbNewLine+vbNewLine+"Our script will not send any data that is not related to Personify ChromaCam or Presenter products."+vbNewLine+vbNewLine+"Press Yes to continue." "VBYesNo+VBQuestion+vbSystemModal" "Collecting Personify logs/events"

if errorlevel 7 (
    echo NO - Do nothing
    exit /b 0
)
set OS_bitness=64bit
if %PROCESSOR_ARCHITECTURE% == x86 (
    if not defined PROCESSOR_ARCHITEW6432 (
        set OS_bitness=32BIT
    )
)
echo YES - Start collecting
echo 1/9. Create temp folder
if exist "%userprofile%\documents\personify_debug" (
    rd "%userprofile%\documents\personify_debug" /S /Q 2>nul
)
mkdir "%userprofile%\documents\personify_debug"

echo 2/9. Run psy_checker for AVX2 and OpenCL1.2 support
psy_checker\win32\PsySystemCheck.exe >> "%userprofile%\documents\personify_debug\psy_checker_32_log.txt" 2>&1
if "%OS_bitness%" == "64bit" (
    psy_checker\win64\PsySystemCheck.exe >> "%userprofile%\documents\personify_debug\psy_checker_64_log.txt" 2>&1
)

echo 3/9. Run personify_test 32 bit - may take one minute
if exist tests\test_win32\PersonifyApiTest.dll (
    copy tests\test_win32\PersonifyApiTest.dll tests\test_win32\PersonifyApiTest.exe /Y >>nul
    tests\test_win32\PersonifyApiTest.exe -d tests\2due_seq.h5 --default-colorcam -f 102 >> "%userprofile%\documents\personify_debug\personify_test_win32_2DUE_log.txt" 2>&1
    tests\test_win32\PersonifyApiTest.exe -d tests\3due_seq.h5 -f 102 >> "%userprofile%\documents\personify_debug\personify_test_win32_3DUE_log.txt" 2>&1
    taskkill /im PersonifyApiTest.exe /f 2>nul
    del tests\test_win32\PersonifyApiTest.exe /Q 2>nul
)

echo 4/9. Run personify_test 64 bit - may take one minute
if "%OS_bitness%" == "64bit" (
    if exist tests\test_win64\PersonifyApiTest.dll (
        copy tests\test_win64\PersonifyApiTest.dll tests\test_win64\PersonifyApiTest.exe /Y >>nul
        tests\test_win64\PersonifyApiTest.exe -d tests\2due_seq.h5 --default-colorcam -f 102 >> "%userprofile%\documents\personify_debug\personify_test_win64_2DUE_log.txt" 2>&1
        tests\test_win64\PersonifyApiTest.exe -d tests\3due_seq.h5 -f 102 >> "%userprofile%\documents\personify_debug\personify_test_win64_3DUE_log.txt" 2>&1
        taskkill /im PersonifyApiTest.exe /f 2>nul
        del tests\test_win64\PersonifyApiTest.exe /Q 2>nul
    )
)

echo 5/9. Collect system information [msinfo32] - may take one minute
msinfo32 /nfo "%userprofile%\documents\personify_debug\system_info.nfo"

echo 6/9. Collect hardware information [dxdiag]
start /w dxdiag /t "%userprofile%\documents\personify_debug\dxdiag_info.txt"

echo 7/9. Collect event logs
wevtutil epl Application "%userprofile%\documents\personify_debug\event.evtx" /q:"*[System[(Level=1  or Level=2 or Level=3) and TimeCreated[timediff(@SystemTime) <= 604800000]]]"

echo 8/9. Copy Personify logs and crashdump files
xcopy "%AppData%\personify\*.log" "%userprofile%\documents\personify_debug\personify_log\" /Y /Q 2>nul
xcopy "%LocalAppData%\personify\*.log" "%userprofile%\documents\personify_debug\personify_log\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\personify_log" (
    cd /d "%userprofile%\documents\personify_debug\personify_log\"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyApiTest*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyChromaCam*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyChromaCamSetup*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyChromaCamUninstall*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyPresenter*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PersonifyCameoUI*.*') do @del "%%F"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d PsySystemCheck*.*') do @del "%%F"
)
xcopy "%LocalAppData%\nuvixa\live\*.txt" "%userprofile%\documents\personify_debug\nuvixa_live\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\nuvixa_live" (
    cd /d "%userprofile%\documents\personify_debug\nuvixa_live\"
    for /f "skip=20 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)
xcopy "%LocalAppData%\CrashDumps\Personify ChromaCam.exe.*.dmp" "%userprofile%\documents\personify_debug\ChromaCamDumps\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\ChromaCamDumps" (
    cd /d "%userprofile%\documents\personify_debug\ChromaCamDumps\"
    for /f "skip=2 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)
xcopy "%LocalAppData%\CrashDumps\PersonifyLive.exe.*.dmp" "%userprofile%\documents\personify_debug\PersonifyLiveDumps\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\PersonifyLiveDumps" (
    cd /d "%userprofile%\documents\personify_debug\PersonifyLiveDumps\"
    for /f "skip=4 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)
xcopy "%userprofile%\AppData\LocalOmniPersonifyOmni.*.dmp" "%userprofile%\documents\personify_debug\LocalOmniDumps\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\LocalOmniDumps" (
    cd /d "%userprofile%\documents\personify_debug\LocalOmniDumps\"
    for /f "skip=4 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)
xcopy "%LocalAppData%\CrashDumps\Personify ChromaCam.ax.*.dmp" "%userprofile%\documents\personify_debug\ChromaCam.ax.Dumps\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\ChromaCam.ax.Dumps" (
    cd /d "%userprofile%\documents\personify_debug\ChromaCam.ax.Dumps\"
    for /f "skip=4 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)
xcopy "%LocalAppData%\CrashDumps\Personify Presenter.*.dmp" "%userprofile%\documents\personify_debug\PresenterDumps\" /Y /Q 2>nul
if exist "%userprofile%\documents\personify_debug\PresenterDumps" (
    cd /d "%userprofile%\documents\personify_debug\PresenterDumps\"
    for /f "skip=4 eol=: delims=" %%F in ('dir /b /o-d *.*') do @del "%%F"
)

echo 9/9. Completed
explorer "%userprofile%\documents\personify_debug"
call :MsgBox "Please review and zip all the files at %userprofile%\documents\personify_debug and send to support@personifyinc.com."+vbNewLine+vbNewLine+"Thank you for your patience!" "vbOKOnly+vbInformation+vbSystemModal" "Collect Personify logs/events"
exit /b 0

:MsgBox prompt type title
    setlocal enableextensions
    set "tempFile=%temp%\%~nx0.%random%%random%%random%vbs.tmp"
    >"%tempFile%" echo(WScript.Quit msgBox("%~1",%~2,"%~3") & cscript //nologo //e:vbscript "%tempFile%"
    set "exitCode=%errorlevel%" & del "%tempFile%" >nul 2>nul
    endlocal & exit /b %exitCode%
